HTTP_STATUS_CODE = {
    200: 'SUCCESS',
    201: 'CREATE',
    204: 'NO CONTENT',
    400: 'BAD REQUEST',
    401: 'UNAUTHORIZED',
    403: 'FORBIDDEN',
    404: 'NOT FOUND',
    405: 'METHOD NOT ALLOWED',
    409: 'CONFLICT',
    500: 'INTERNAL SERVER ERROR',
    422: 'UNPROCESSABLE ENTITY',
    429: 'TOO MANY REQUESTS',
}